

# hf_cleaner

`hf_cleaner` is a simple Python package that provides utility to view and delete hugging face models downloaded in the local cache.
Works for windows, linux and MacOS

## Installation

```bash
pip install hf_cleaner
```

## CLI caller

```bash
hf_cleaner
```